# include <QtGui>

# include "bildumwandlung.h"

bildumwandlung::bildumwandlung(QWidget *parent): QDialog(parent)
{
	setupUi(this);

	QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
	QTimer::singleShot(0, this, SLOT(converttest()));

	connect(openButton, SIGNAL(clicked()), this, SLOT(openDialog()));
	connect(processButton, SIGNAL(clicked()), this, SLOT(process()));

	connect(&proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(ProcBeendet(int, QProcess::ExitStatus)));
}

bool caseInsensitiveLessThan(const QString &s1, const QString &s2)
{
	return s1.toLower() > s2.toLower();
}

void bildumwandlung::openDialog()
{
	QString initialDir = openLineEdit->text();
	if(initialDir.isEmpty())
		initialDir = QDir::homePath();

	QStringList InputFiles = QFileDialog::getOpenFileNames(
		this,
		"Open File(s)",
		initialDir,
		"Bitmap (*.bmp);;All Files(*.*)");

	qSort(InputFiles.begin(),InputFiles.end(),caseInsensitiveLessThan);

	if(!InputFiles.isEmpty())
		{
		QFileInfo file(InputFiles[0]);
		QString FilePath = InputFiles[0];
		FilePath.remove(file.fileName());
		openLineEdit->setText(FilePath);

		TableWidget->clear();
		TableWidget->setRowCount(0);
		TableWidget->setColumnCount(2);
		TableWidget->horizontalHeader()->resizeSection(0,250);
		TableWidget->horizontalHeader()->resizeSection(1,60);
		TableWidget->setHorizontalHeaderItem(0, new QTableWidgetItem("Files"));
		TableWidget->setHorizontalHeaderItem(1, new QTableWidgetItem("Status"));

		foreach (QString str, InputFiles)
			{
			str.remove(FilePath);
			TableWidget->insertRow(0);
			TableWidget->setItem(0,0, new QTableWidgetItem(str));
			}
		processButton->setEnabled(true);
		progressBar->setValue(0);
		position=0;
		}
}

void bildumwandlung::process()
{
	openButton->setEnabled(false);
	processButton->setEnabled(false);
	QApplication::setOverrideCursor(Qt::WaitCursor);

	QString Input,Output;
	anzahl = TableWidget->rowCount();

	Input = openLineEdit->text()+TableWidget->item(position,0)->text();
	Output = openLineEdit->text()+QFileInfo(Input).completeBaseName()+".jpg";

	QStringList arg;
	arg << "-format" << "jpg" << "-quality" << "90" << Input << Output;
	proc.start("convert", arg);
}

void bildumwandlung::ProcBeendet(int exitCode, QProcess::ExitStatus exitStatus)
{
	if (exitStatus==QProcess::CrashExit || exitCode!=0)
		{
		openButton->setEnabled(true);
		processButton->setEnabled(true);
		QApplication::restoreOverrideCursor();
		QMessageBox::critical(this, tr("Bildumwandlung"),
			tr("Fehler bei der Konvertierung!"
			"Fehlende Schreibrechte?"),
			QMessageBox::Ok);
		}
	else	{
		TableWidget->setItem(position,1, new QTableWidgetItem(tr("Fertig.")));
		if(position<anzahl-1)
			{
			QApplication::restoreOverrideCursor();
			position++;
			updateProgressbar();
			process();
			}
		else if(position==anzahl-1)
			{
			progressBar->setValue(100);
			openButton->setEnabled(true);
			QApplication::restoreOverrideCursor();
			}
		}
}

void bildumwandlung::updateProgressbar()
{
	double prozent = (double)position/(double)anzahl*100;
	int value = (int)prozent;
	progressBar->setValue(value);
}

void bildumwandlung::converttest()
{
	QFileInfo test("/usr/bin/convert");
	if(!test.exists())
		{
		QMessageBox msgBox;
		msgBox.setStandardButtons(QMessageBox::Ok);
		msgBox.setIcon(QMessageBox::Critical);
		msgBox.setWindowTitle(tr("Bildumwandlung-Fehler"));
		msgBox.setText(tr("<b>Fehler: convert nicht gefunden!</b><br><br>"
			"Bitte installieren Sie convert<br>"
			"und starten sie das Programm neu.<br><br>"
			"Das Programm wird geschlossen."));
		msgBox.exec();
		QCoreApplication::exit(2);
		}
}